`pylidc` is a python library intended to improve workflow associated with the [LIDC dataset](https://wiki.cancerimagingarchive.net/display/Public/LIDC-IDRI).

Install via pip: `pip install pylidc`.

[See the full documentation and tutorials here.](https://pylidc.github.io)
